@@ -1,6 +1,3 @@
-use std::thread::sleep;
-use std::time::{Duration, Instant};
-
 mod test_common;
 
 #[cfg(feature = "frontpanel")]
